<?php
declare(strict_types=1);

namespace Inti\Wp\Plugin;

/**
 * Class PluginLoader
 *
 * @package Inti\Wp\Plugin
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-wp
 */
final class PluginLoader implements PluginInterface
{
    /** @var string[] */
    private $plugins;
    /** @var PluginPluginManager */
    private $pluginManager;

    /**
     * Konstruktor.
     *
     * @param string[] $plugins
     * @param PluginPluginManager $pluginManager
     */
    public function __construct(array $plugins, PluginPluginManager $pluginManager)
    {
        $this->plugins = $plugins;
        $this->pluginManager = $pluginManager;
    }

    public function attachEarly(): void
    {
        foreach ($this->plugins as $name) {
            /** @var PluginInterface $plugin */
            $plugin = $this->pluginManager->get($name);
            $plugin->attachEarly();
        }
    }

    /**
     * Attaches all the plugins.
     */
    public function attach(): void
    {
        foreach ($this->plugins as $name) {
            /** @var PluginInterface $plugin */
            $plugin = $this->pluginManager->get($name);
            $plugin->attach();
        }
    }
}
